==> nmail-php-patch-2.3.0-to-2.3.1.tgz: nmail/include/auto_filter_lib.php <==
<? if ( !defined("_INCLUDED_GLOBAL") ) die("Access Denied");		// [Security]Allow_url_fopen = On ?>
<?

	function get_auto_filter_vars()
	{
		$condition = array(
			'SUBJ'=>"<u></u>  ܾ ϳ Ե ",
			'BODY'=>"<u></u>  ܾ ϳ Ե ",
			'FROM'=>"<u>  ּ</u>  ּҿ ġϴ ",
			'FROM2'=>"<u>  ּ</u>  ܾ ϳ Ե ",
			'MY_Y'=>"<u>޴ </u>̳ <u></u>  ּҰ ִ ",
			'MY_N'=>"<u>޴ </u>̳ <u></u>  ּҰ  ",
			'FILE_Y'=>"<u>÷</u> ִ ",
			'FILE'=>"<u>÷ϸ</u>  ܾ ϳ Ե "
			);

		$exec = array(
			'MOVE'=>"  ̵ (/ӽ/ )",
			'READ'=>" Ϸ ǥ",
			'DEL'=>"Կ  ʰ  "
			);

		$condition_input = array(
			'SUBJ'=>"I",
			'BODY'=>"I",
			'FROM'=>"I",
			'FROM2'=>"I",
			'MY_Y'=>"N",
			'MY_N'=>"N",
			'FILE_Y'=>"N",
			'FILE'=>"I"
			);

		$exec_input = array(
			'MOVE'=>"MAILBOX",
			'READ'=>"N",
			'DEL'=>"N"
			);

		$as_vars = array(
			'condition'=>$condition,
			'condition_input'=>$condition_input,
			'exec'=>$exec,
			'exec_input'=>$exec_input
			);
		/*
				$as_vars = array(
			'condition_key'=>array_keys($condition),
			'condition_key'=>array_values($condition),
			$exec);
*/

		return $as_vars;
	}	// function()


	//  Ŀ ° ȯ.
	function set_auto_filter_vars()
	{
		global $G_SYS;
		$_POST['as_condition'] = '';
		$_POST['as_condition_text'] = '';
		for ($i=0; $i<sizeof($_POST['condt_chk']); $i++)
		{
			$_POST['as_condition'] .= str_replace('|', '', $_POST['condt_chk'][$i]);
			$_POST['as_condition_text'] .= str_replace('|', '', set_auto_filter_trim($_POST['condt_'.$_POST['condt_chk'][$i]]));
			if ($i+1 != sizeof($_POST['condt_chk']))
			{
				$_POST['as_condition'] .= '|';
				$_POST['as_condition_text'] .= '|';
			}	// if()
		}	// for()

		$_POST['as_exec'] = '';
		$_POST['as_exec_text'] = '';
		for ($i=0; $i<sizeof($_POST['exec_chk']); $i++)
		{
			$_POST['as_exec'] .= str_replace('|', '', $_POST['exec_chk'][$i]);
			$_POST['as_exec_text'] .= str_replace('|', '', set_auto_filter_trim($_POST['exec_'.$_POST['exec_chk'][$i]]));
			if ($i+1 != sizeof($_POST['exec_chk']))
			{
				$_POST['as_exec'] .= '|';
				$_POST['as_exec_text'] .= '|';
			}	// if()
		}	// for()

		$_POST['as_econdition'] = '';
		$_POST['as_econdition_text'] = '';
		for ($i=0; $i<sizeof($_POST['econdt_chk']); $i++)
		{
			$_POST['as_econdition'] .= str_replace('|', '', $_POST['econdt_chk'][$i]);
			$_POST['as_econdition_text'] .=  str_replace('|', '', set_auto_filter_trim($_POST['econdt_'.$_POST['econdt_chk'][$i]]));
			if ($i+1 != sizeof($_POST['econdt_chk']))
			{
				$_POST['as_econdition'] .= '|';
				$_POST['as_econdition_text'] .= '|';
			}	// if()
		}	// for()

		// length cechk
		if (strlen($_POST['as_condition_text']) > $G_SYS['DB_TEXT'])
			msg("[ ] ϵ ܾ  ̰ ".number_format($G_SYS['DB_TEXT'])."ڸ ʰϿ   ϴ.");
		if (strlen($_POST['as_exec_text']) > $G_SYS['DB_TEXT'])
			msg("[ ] ϵ ܾ  ̰ ".number_format($G_SYS['DB_TEXT'])."ڸ ʰϿ   ϴ.");
		if (strlen($_POST['as_econdition_text']) > $G_SYS['DB_TEXT'])
			msg("[  ] ϵ ܾ  ̰ ".number_format($G_SYS['DB_TEXT'])."ڸ ʰϿ   ϴ.");

		// addslashes
		$_POST['as_condition_text'] = addslashes($_POST['as_condition_text']);
		$_POST['as_exec_text'] = addslashes($_POST['as_exec_text']);
		$_POST['as_econdition_text'] = addslashes($_POST['as_econdition_text']);
	}	// function()

	function set_auto_filter_trim($value)
	{
		$_ex = explode(',', $value);
		$str = '';
		for ($i=0; $i<sizeof($_ex); $i++)
		{
			$_str = trim($_ex[$i]);
			if ($_str != '')
			{
				if ($str != '')
					$str .= ',';
				$str .= $_str;
			}	// if()
		}	// for()
		return $str;
	}	// function()

	/*
		-.  ڵз /  Ÿ .

		ex)
			$view = setform_auto_filter($row);

	*/
	function setform_auto_filter($row, $as)
	{
		global $G, $G_SYS, $TB, $AUTH;

		// default
		if ($row['as_sort'] == '')
		{
			$sql = "SELECT MAX(as_sort) FROM ".$TB['AUTO_FILTER']." WHERE m_no='" . $AUTH['auth_m_no'] . "'";
			$row['as_sort'] = db_get_one($sql) + 1;
		}	// if()

		// set
		$view['as_name'] = input_value($row['as_name'], 1);
		$view['as_is_use'] = select_list_value($row['as_is_use'], array_values($G[ISUSE]), array_keys($G[ISUSE]), NULL, 0, 1);
		$view['as_sort'] = input_value($row['as_sort'], 1);

		//  
		$mb_id = 'spam';

		$_ex = explode('|', $row['as_condition']);
		$_ex2 = explode('|', $row['as_condition_text']);
		$view['as_condition_ischk'] = array();
		$view['as_condition_value'] = array();
		foreach ($as['condition'] as $key=>$val)
		{
			$_as = array_search($key, $_ex);
			if ($_as !== false)
			{
				$view['as_condition_ischk'][$key] = true;
				$view['as_condition_value'][$key] = htmlspecialchars_fix($_ex2[$_as]);
			}	// if()
		}	// foreach()

		$_ex = explode('|', $row['as_exec']);
		$_ex2 = explode('|', $row['as_exec_text']);
		$view['as_exec_ischk'] = array();
		$view['as_exec_value'] = array();
		foreach ($as['exec'] as $key=>$val)
		{
			$_as = array_search($key, $_ex);
			if ($_as !== false)
			{
				$view['as_exec_ischk'][$key] = true;
				$view['as_exec_value'][$key] = input_value($_ex2[$_as], 1);
				if ($key == 'MOVE')
				{
					$mb_id = $_ex2[$_as];
				}	// if()
			}	// if()
		}	// foreach()

		$_ex = explode('|', $row['as_econdition']);
		$_ex2 = explode('|', $row['as_econdition_text']);
		$view['as_econdition_ischk'] = array();
		$view['as_econdition_value'] = array();
		foreach ($as['condition'] as $key=>$val)
		{
			$_as = array_search($key, $_ex);
			if ($_as !== false)
			{
				$view['as_econdition_ischk'][$key] = true;
				$view['as_econdition_value'][$key] = htmlspecialchars_fix($_ex2[$_as]);
			}	// if()
		}	// foreach()


		// Ϲڽ
			$mail_box = get_mail_box();
			$_mail_box = array();
			for ($i=0; $i<sizeof($mail_box); $i++)
			{
				if (get_mb_dir($mail_box[$i]['mb_id']) == get_mb_dir('inbox'))
				{
					$_mail_box['mb_name'][] = $mail_box[$i]['mb_name'];
					$_mail_box['mb_id'][] = $mail_box[$i]['mb_id'];
				}	// if()
			}	// for()
			$view['select_mail_box'] = select_list_value($mb_id, $_mail_box['mb_name'], $_mail_box['mb_id'], NULL, 0, 1);

		return $view;
	}	// function()


	function get_auto_filter_value($keys, $texts, $vars)
	{
		$_ex = explode('|', $keys);
		$_ex2 = explode('|', $texts);
		$str = '';
		foreach ($vars as $key=>$val)
		{
			$_as = array_search($key, $_ex);
			if ($_as !== false)
			{
				$str .= "<div style='HEIGHT:15px; OVERFLOW:hidden;'>".$val."</div>";
				if ($_ex2[$_as])
				{
					if ($key == 'MOVE')
					{
						$_ex2[$_as] = get_mb_name($_ex2[$_as]);
					}	// if()
					$str .= "<div style='HEIGHT:15px; OVERFLOW:hidden;'>&nbsp; : <font color=#363636>".han_substr($_ex2[$_as], 25)."</font></div>";
				}	// if()
			}	// if()
		}	// foreach()

		return $str;
	}	// function()


	// ִ   .
	function limit_auto_filter_max()
	{
		global $TB, $AUTH, $G_SYS;
		$sql = "
			SELECT
				COUNT(*)
			FROM
				" . $TB['AUTO_FILTER'] . "
			WHERE
				m_no='" . $AUTH['auth_m_no'] . "'
			";
		$as_cnt = db_get_one($sql);
		if ($as_cnt >= $G_SYS['AUTO_FILTER_MAX'])
		{
			msg("ִ ".$G_SYS['AUTO_FILTER_MAX']."   ֽϴ.");
		}	// if()
	}	// function()


?>

==> nmail-php-patch-2.5.2-to-2.6.1.tgz: nmail/include/auto_filter_lib.php <==
<? if ( !defined("_INCLUDED_GLOBAL") ) die("Access Denied");		// [Security]Allow_url_fopen = On ?>
<?

	function get_auto_filter_vars()
	{
		$condition = array(
			'SUBJ'=>"<u></u>  ܾ ϳ Ե ",
			'BODY'=>"<u></u>  ܾ ϳ Ե ",
			'FROM'=>"<u>  ּ</u>  ּҿ ġϴ ",
			'FROM2'=>"<u>  ּ</u>  ܾ ϳ Ե ",
			'TO'=>"<u>޴  ּ</u>  ּҿ ġϴ ",
			'TO2'=>"<u>޴  ּ</u>  ܾ ϳ Ե ",
			'CC'=>"<u> ּ</u>  ּҿ ġϴ ",
			'CC2'=>"<u> ּ</u>  ܾ ϳ Ե ",
			'MY_Y'=>"<u>޴ </u>̳ <u></u>  ּҰ ִ ",
			'MY_N'=>"<u>޴ </u>̳ <u></u>  ּҰ  ",
			'FILE_Y'=>"<u>÷</u> ִ ",
			'FILE'=>"<u>÷ϸ</u>  ܾ ϳ Ե "
			);

		$exec = array(
			'MOVE'=>"  ̵ (/ӽ/ )",
			'READ'=>" Ϸ ǥ",
			'DEL'=>"Կ  ʰ  "
			);

		$condition_input = array(
			'SUBJ'=>"I",
			'BODY'=>"I",
			'FROM'=>"I",
			'FROM2'=>"I",
			'TO'=>"I",
			'TO2'=>"I",
			'CC'=>"I",
			'CC2'=>"I",
			'MY_Y'=>"N",
			'MY_N'=>"N",
			'FILE_Y'=>"N",
			'FILE'=>"I"
			);

		$exec_input = array(
			'MOVE'=>"MAILBOX",
			'READ'=>"N",
			'DEL'=>"N"
			);

		$as_vars = array(
			'condition'=>$condition,
			'condition_input'=>$condition_input,
			'exec'=>$exec,
			'exec_input'=>$exec_input
			);
		/*
				$as_vars = array(
			'condition_key'=>array_keys($condition),
			'condition_key'=>array_values($condition),
			$exec);
*/

		return $as_vars;
	}	// function()


	//  Ŀ ° ȯ.
	function set_auto_filter_vars()
	{
		global $G_SYS;
		$_POST['as_condition'] = '';
		$_POST['as_condition_text'] = '';
		for ($i=0; $i<sizeof($_POST['condt_chk']); $i++)
		{
			$_POST['as_condition'] .= str_replace('|', '', $_POST['condt_chk'][$i]);
			$_POST['as_condition_text'] .= str_replace('|', '', set_auto_filter_trim($_POST['condt_'.$_POST['condt_chk'][$i]]));
			if ($i+1 != sizeof($_POST['condt_chk']))
			{
				$_POST['as_condition'] .= '|';
				$_POST['as_condition_text'] .= '|';
			}	// if()
		}	// for()

		$_POST['as_exec'] = '';
		$_POST['as_exec_text'] = '';
		for ($i=0; $i<sizeof($_POST['exec_chk']); $i++)
		{
			$_POST['as_exec'] .= str_replace('|', '', $_POST['exec_chk'][$i]);
			$_POST['as_exec_text'] .= str_replace('|', '', set_auto_filter_trim($_POST['exec_'.$_POST['exec_chk'][$i]]));
			if ($i+1 != sizeof($_POST['exec_chk']))
			{
				$_POST['as_exec'] .= '|';
				$_POST['as_exec_text'] .= '|';
			}	// if()
		}	// for()

		$_POST['as_econdition'] = '';
		$_POST['as_econdition_text'] = '';
		for ($i=0; $i<sizeof($_POST['econdt_chk']); $i++)
		{
			$_POST['as_econdition'] .= str_replace('|', '', $_POST['econdt_chk'][$i]);
			$_POST['as_econdition_text'] .=  str_replace('|', '', set_auto_filter_trim($_POST['econdt_'.$_POST['econdt_chk'][$i]]));
			if ($i+1 != sizeof($_POST['econdt_chk']))
			{
				$_POST['as_econdition'] .= '|';
				$_POST['as_econdition_text'] .= '|';
			}	// if()
		}	// for()

		// length cechk
		if (strlen($_POST['as_condition_text']) > $G_SYS['DB_TEXT'])
			msg("[ ] ϵ ܾ  ̰ ".number_format($G_SYS['DB_TEXT'])."ڸ ʰϿ   ϴ.");
		if (strlen($_POST['as_exec_text']) > $G_SYS['DB_TEXT'])
			msg("[ ] ϵ ܾ  ̰ ".number_format($G_SYS['DB_TEXT'])."ڸ ʰϿ   ϴ.");
		if (strlen($_POST['as_econdition_text']) > $G_SYS['DB_TEXT'])
			msg("[  ] ϵ ܾ  ̰ ".number_format($G_SYS['DB_TEXT'])."ڸ ʰϿ   ϴ.");

		// addslashes
		$_POST['as_condition_text'] = addslashes($_POST['as_condition_text']);
		$_POST['as_exec_text'] = addslashes($_POST['as_exec_text']);
		$_POST['as_econdition_text'] = addslashes($_POST['as_econdition_text']);
	}	// function()

	function set_auto_filter_trim($value)
	{
		// [2013-07-09] addslashes ߺ  .
		//$_ex = explode(',', $value);
		$_ex = explode(',', stripslashes($value));
		$str = '';
		for ($i=0; $i<sizeof($_ex); $i++)
		{
			$_str = trim($_ex[$i]);
			if ($_str != '')
			{
				if ($str != '')
					$str .= ',';
				$str .= $_str;
			}	// if()
		}	// for()
		return $str;
	}	// function()

	/*
		-.  ڵз /  Ÿ .

		ex)
			$view = setform_auto_filter($row);

	*/
	function setform_auto_filter($row, $as)
	{
		global $G, $G_SYS, $TB, $AUTH;

		// default
		if ($row['as_sort'] == '')
		{
			$sql = "SELECT MAX(as_sort) FROM ".$TB['AUTO_FILTER']." WHERE m_no='" . $AUTH['auth_m_no'] . "'";
			$row['as_sort'] = db_get_one($sql) + 1;
		}	// if()

		// set
		$view['as_name'] = input_value($row['as_name'], 1);
		$view['as_is_use'] = select_list_value($row['as_is_use'], array_values($G[ISUSE]), array_keys($G[ISUSE]), NULL, 0, 1);
		$view['as_sort'] = input_value($row['as_sort'], 1);

		//  
		$mb_id = 'spam';

		$_ex = explode('|', $row['as_condition']);
		$_ex2 = explode('|', $row['as_condition_text']);
		$view['as_condition_ischk'] = array();
		$view['as_condition_value'] = array();
		foreach ($as['condition'] as $key=>$val)
		{
			$_as = array_search($key, $_ex);
			if ($_as !== false)
			{
				$view['as_condition_ischk'][$key] = true;
				$view['as_condition_value'][$key] = htmlspecialchars_fix($_ex2[$_as]);
			}	// if()
		}	// foreach()

		$_ex = explode('|', $row['as_exec']);
		$_ex2 = explode('|', $row['as_exec_text']);
		$view['as_exec_ischk'] = array();
		$view['as_exec_value'] = array();
		foreach ($as['exec'] as $key=>$val)
		{
			$_as = array_search($key, $_ex);
			if ($_as !== false)
			{
				$view['as_exec_ischk'][$key] = true;
				$view['as_exec_value'][$key] = input_value($_ex2[$_as], 1);
				if ($key == 'MOVE')
				{
					$mb_id = $_ex2[$_as];
				}	// if()
			}	// if()
		}	// foreach()

		$_ex = explode('|', $row['as_econdition']);
		$_ex2 = explode('|', $row['as_econdition_text']);
		$view['as_econdition_ischk'] = array();
		$view['as_econdition_value'] = array();
		foreach ($as['condition'] as $key=>$val)
		{
			$_as = array_search($key, $_ex);
			if ($_as !== false)
			{
				$view['as_econdition_ischk'][$key] = true;
				$view['as_econdition_value'][$key] = htmlspecialchars_fix($_ex2[$_as]);
			}	// if()
		}	// foreach()


		// Ϲڽ
			$mail_box = get_mail_box();
			$_mail_box = array();
			for ($i=0; $i<sizeof($mail_box); $i++)
			{
				if (get_mb_dir($mail_box[$i]['mb_id']) == get_mb_dir('inbox'))
				{
					$_mail_box['mb_name'][] = $mail_box[$i]['mb_name'];
					$_mail_box['mb_id'][] = $mail_box[$i]['mb_id'];
				}	// if()
			}	// for()
			$view['select_mail_box'] = select_list_value($mb_id, $_mail_box['mb_name'], $_mail_box['mb_id'], NULL, 0, 1);

		return $view;
	}	// function()


	function get_auto_filter_value($keys, $texts, $vars)
	{
		$_ex = explode('|', $keys);
		$_ex2 = explode('|', $texts);
		$str = '';
		foreach ($vars as $key=>$val)
		{
			$_as = array_search($key, $_ex);
			if ($_as !== false)
			{
				$str .= "<div style='HEIGHT:15px; OVERFLOW:hidden;'>".$val."</div>";
				if ($_ex2[$_as])
				{
					if ($key == 'MOVE')
					{
						$_ex2[$_as] = get_mb_name($_ex2[$_as]);
					}	// if()
					$str .= "<div style='HEIGHT:15px; OVERFLOW:hidden;'>&nbsp; : <font color=#363636>".han_substr($_ex2[$_as], 25)."</font></div>";
				}	// if()
			}	// if()
		}	// foreach()

		return $str;
	}	// function()


	// ִ   .
	function limit_auto_filter_max()
	{
		global $TB, $AUTH, $G_SYS;
		$sql = "
			SELECT
				COUNT(*)
			FROM
				" . $TB['AUTO_FILTER'] . "
			WHERE
				m_no='" . $AUTH['auth_m_no'] . "'
			";
		$as_cnt = db_get_one($sql);
		if ($as_cnt >= $G_SYS['AUTO_FILTER_MAX'])
		{
			msg(" ڵз ִ ".$G_SYS['AUTO_FILTER_MAX']."   ֽϴ.");
		}	// if()
	}	// function()


?>
